[Compare the full difference.](https://github.com/callowayproject/bump-my-version/compare/0.32.1...0.32.2)

### Fixes

- Fixed coverage issue. [b0c46a3](https://github.com/callowayproject/bump-my-version/commit/b0c46a37ff265b5306abf005b5742a85c4281ea2)
    
- Refactor SCMInfo and Config imports. [49995c6](https://github.com/callowayproject/bump-my-version/commit/49995c6a9b2ad59c65cb6c1e27362b1254ce7fb4)
    
  - Fixes #300 incompatibility with Nuitka compiling
### Other

- [pre-commit.ci] pre-commit autoupdate. [b786638](https://github.com/callowayproject/bump-my-version/commit/b786638f152f2044d629c11f38f56713cc5c6dc4)
    
  **updates:** - [github.com/astral-sh/ruff-pre-commit: v0.9.4 → v0.9.6](https://github.com/astral-sh/ruff-pre-commit/compare/v0.9.4...v0.9.6)
